clear all
capture log close
set more off
import excel "PublicLEEDProjectDirectory-CertOnly-061014.xls", sheet("PublicLEEDProjectDirectory-Cert") firstrow clear

/* Sample = Public US Projects*/
drop if Isconfidential == "Yes"
keep if Country == "US"
drop if GrossSqFoot==0
drop if (CertLevel == "Bronze" | CertLevel == "Denied")

/* Create Market IDs (3 Digit Zip) */
gen tmp = regexr(Zipcode,"-.*","")
drop if strlen(tmp) < 4
replace tmp = "0"+tmp if strlen(tmp) == 4
gen zip3 = substr(tmp,1,3)
egen mkt = group(zip3)
drop tmp

/* Merge in Census Data */
merge m:1 zip3 using census2000, keep(3) nogen
drop if highschool==0

/* Create Explanatory Variables */
gen lgGSF=log(GrossSqFoot)
gen certYr = yofd(dofc(CertDate))
gen regYr = yofd(dofc(RegistrationDate))

bysort mkt (CertDate): gen mktOrder = _n 
by mkt: egen ttlCerts = sum(1)
destring PointsAchieved, gen(points) force

gen ownType = "Profit" if regexm(OwnerTypes,"^Profit")
replace ownType = "Non-Profit" if regexm(OwnerTypes,"^Non-Profit")
replace ownType = "Profit" if (regexm(OwnerTypes,"^Corporate") | regexm(OwnerTypes,"^Investor"))
replace ownType = "Education" if regexm(OwnerTypes,"^Education")
replace ownType = "Govt" if (regexm(OwnerTypes,"^Federal") | regexm(OwnerTypes,"^State")|regexm(OwnerTypes,"^Local")|regexm(OwnerTypes,"^Govern"))
replace ownType = "Other" if (ownType == "" & Isconfidential == "No")
egen ot = group(ownType)

gen pop = exp(lgpop) / 1000
gen inc = exp(lg_medianincome) /1000
gen hous = exp(lghousing) / 1000

gen level = 1 if CertLevel == "Certified"
replace level = 2 if CertLevel == "Silver"
replace level = 3 if CertLevel == "Gold"
replace level = 4 if CertLevel == "Platinum"

* Lagged Y as running avg.
bysort mkt (mktOrder): gen prevMean = level
bysort mkt (mktOrder): replace prevMean = ((_n-2)*prevMean[_n-1] + level[_n-1])/(_n-1) if _n>2
bysort mkt (mktOrder): replace prevMean=. if _n==1

gen aboveMean=(level>prevMean)
gen aboveRounded=(level>round(prevMean))

* Very few observations before year 2003 
gen pre2004=(certYr<2004)
replace certYr=2003 if pre2004==1



/** FIGURE 1 **/
set scheme s2mono
graph bar (count) mkt if certYr > 2000, over(certYr,  label(angle(vertical))) ytitle("LEED Certifications (Count)" " ")
graph export figures/certYrs.pdf, replace


/** FIGURE 2 **/
gen pre2009 = regexm(LEEDSystemVersionDisplayName, "LEED-NC 2")
count if pre2009
hist points if pre2009 & points>=20, freq xline(26 33 39 52) xlabel(26 33 39 52) ytitle("Count of Certified Buildings" " ")
graph export figures/notches.pdf, replace


/** FIGURE A1 **/
graph bar (percent) points if certYr>=2004, over(level) over(certYr) asyvar percent stack ytitle("Percent of Certifications" " ") legend(lab(1 "Certified") lab(2 "Silver") lab(3 "Gold") lab(4 "Platinum"))
graph export figures/certShareYrs.pdf, replace


/** FIGURE A2 **/
gen lnTtlCerts = log(ttlCerts)
hist lnTtlCerts if mktOrder == 1, freq xtitle("log(Total Certifications)")
graph export figures/certHist.pdf, replace



log using leedResults.log, t replace
/** SUMMARY STATS **/ 
tab ttlCerts if (mktOrder == 1)
tab ownType CertLevel, row nofreq


/** TABLE 1: Summary Stats **/
format pop inc hous rent vacancy highschool college renterocc %4.2f 
sum pop inc hous rent vacancy renterocc highschool college if ttlCerts>=2 & mktOrder == 1, format


/** TABLE 2: MTAD **/
gen lev1 = (level == 1)
gen lev2 = (level == 1 | level == 2)
gen lev4 = (level == 4)

mtad level, m(mkt) niter(250)
mtad lev1, m(mkt) niter(250)
mtad lev2, m(mkt) niter(250)
mtad lev4, m(mkt) niter(250)


/** TABLE A1: MTAD by Size **/
mtad level if ttlCerts<10, m(mkt) niter(250)
mtad level if ttlCerts>=10 & ttlCerts<20, m(mkt) niter(250)
mtad level if ttlCerts>=20 & ttlCerts<30, m(mkt) niter(250)
mtad level if ttlCerts>=30 & ttlCerts<40, m(mkt) niter(250)
mtad level if ttlCerts>=40, m(mkt) niter(250)



/** TABLE 3: Reduced Forms */
eststo col1: oprobit level prevMean lgGSF i.ot  lgpop lg_medianincome   lghousing rent vacancy renterocc   highschool college   i.certYr, vce(cluster mkt)
eststo col2: regress level prevMean lgGSF i.ot  lgpop lg_medianincome   lghousing rent vacancy renterocc   highschool college   i.certYr, vce(cluster mkt)
eststo col3: probit aboveMean prevMean lgGSF i.ot  lgpop lg_medianincome   lghousing rent vacancy renterocc   highschool college   i.certYr, vce(cluster mkt)
eststo col4: regress aboveMean prevMean lgGSF i.ot  lgpop lg_medianincome   lghousing rent vacancy renterocc   highschool college   i.certYr, vce(cluster mkt)
estout _all, cells(b(fmt(3)) se(par([ ]) fmt(3) star)) starlevels(* 0.05 ** 0.01) stats(N ll, fmt(0 0)) label
est clear

/** TABLE A2: Reduced Form No Controls */
eststo col1: oprobit level prevMean, vce(cluster mkt)
eststo col2: regress level prevMean, vce(cluster mkt)
eststo col3: probit aboveMean prevMean, vce(cluster mkt)
eststo col4: regress aboveMean prevMean, vce(cluster mkt)
estout _all, cells(b(fmt(3)) se(par([ ]) fmt(3) star)) starlevels(* 0.05 ** 0.01) stats(N ll, fmt(0 0)) label
est clear

** Economic Significance
probit aboveMean prevMean lgGSF i.ot  lgpop lg_medianincome lghousing rent vacancy renterocc   highschool college   i.certYr, vce(cluster mkt)
margins, at(prevMean = (1 2 3 4)) predict(xb)
margins, at(prevMean = (1 2 3 4))

** Robustness to Rounding
eststo col1: probit aboveRound prevMean lgGSF i.ot  lgpop lg_medianincome   lghousing rent vacancy renterocc   highschool college   i.certYr, vce(cluster mkt)
eststo col2: regress aboveRound prevMean lgGSF i.ot  lgpop lg_medianincome   lghousing rent vacancy renterocc   highschool college   i.certYr, vce(cluster mkt)
estout _all, cells(b(fmt(3)) se(par([ ]) fmt(3) star)) starlevels(* 0.05 ** 0.01) stats(N ll, fmt(0 0)) label
est clear



/** TABLE 4: Mean Reversion **/
merge 1:1 ID using level_simu
tab mktOrder if _merge == 1
drop _merge
gen aboveMean_simu=(level_simu>prevMean)

eststo col1: oprobit level prevMean lgGSF i.ot  lgpop lg_medianincome   lghousing rent vacancy renterocc   highschool college   i.certYr, vce(cluster mkt)
eststo col2: oprobit level_simu prevMean lgGSF i.ot  lgpop lg_medianincome   lghousing rent vacancy renterocc   highschool college   i.certYr, vce(cluster mkt)
eststo col3: probit aboveMean prevMean lgGSF i.ot  lgpop lg_medianincome   lghousing rent vacancy renterocc   highschool college   i.certYr, vce(cluster mkt)
eststo col4: probit aboveMean_simu prevMean lgGSF i.ot  lgpop lg_medianincome   lghousing rent vacancy renterocc   highschool college   i.certYr, vce(cluster mkt)
estout _all, cells(b(fmt(3)) se(par([ ]) fmt(3) star)) starlevels(* 0.05 ** 0.01) stats(N ll, fmt(0 0)) label
log close


/** TABLE 5: Indirect Inference **/

* This code prepares the data for indirect inference estimation in Matlab
gen n=_n
tabulate certYr,gen(yr)
tabulate ot,gen(ot)
tabulate mkt,gen(mkt)

keep n mkt mktOrder level lgGSF  ot2-ot5 lgpop lg_medianincome   lghousing rent vacancy renterocc   highschool college  yr2-yr12 mkt1-mkt778 prevMean
order n mkt mktOrder level lgGSF ot2-ot5 lgpop lg_medianincome   lghousing rent vacancy renterocc   highschool college  yr2-yr12 mkt1-mkt778 prevMean
*outsheet using "leediiCSA.csv", replace
